use v6.c;

use Foo;
